export interface GraphQLServiceConfig {
    schemaCacheSettings?: SchemaCacheSettings | "NoCache";
    disableAuthentication?: boolean;
    disableExplorer?: boolean;
    realmCacheMaxAge?: number;
    forceExplorerSSL?: boolean;
    includeCountInResponses?: boolean;
    presentIntsAsFloatsInSchema?: boolean;
    collectionModelSuffix?: string;
    inputModelSuffix?: string;
    namedSubscriptionModelName?: string;
    base64ModelName?: string;
    allRealmTypesModelName?: string;
}
export interface SchemaCacheSettings {
    max?: number;
    maxAge?: number;
}
export declare class GraphQLService {
    private readonly schemaCache;
    private readonly disableAuthentication;
    private readonly realmCacheTTL;
    private readonly disableExplorer;
    private readonly schemaHandlers;
    private readonly forceExplorerSSL;
    private readonly includeCountInResponses;
    private readonly presentIntsAsFloatsInSchema;
    private readonly collectionModelSuffix;
    private readonly inputModelSuffix;
    private readonly namedSubscriptionModelName;
    private readonly base64Type;
    private readonly allRealmTypesName;
    private server;
    private subscriptionServer;
    private handler;
    private graphiql;
    private pubsub;
    private querySubscriptions;
    private adminRealm;
    private linkingObjectsResolver;
    constructor(config?: GraphQLServiceConfig);
    private serverStarted;
    private start;
    private stop;
    private subscriptionHandler;
    private getExplore;
    private postExplore;
    private get;
    private post;
    private deleteSchema;
    private getPath;
    private authenticateRequest;
    private authenticate;
    private validateAccess;
    private closeRealm;
    private validateRead;
    private validateWrite;
    private getSchema;
    private setupGetAllObjects;
    private setupAddObject;
    private setupSubscribeToQuery;
    private setupGetObjectByPK;
    private setupUpdateObject;
    private setupDiffUpdateObject;
    private setupDeleteObject;
    private setupDeleteObjects;
    private setupCreatePartialSubscription;
    private setupListPartialSubscriptions;
    private setupDeletePartialSubscription;
    private upsertObject;
    private getPropertySchema;
    private getTypeString;
    private getPrimitiveTypeString;
    private getCollectionType;
    private getCollectionResponse;
    private resolveLinkingObjectsTypeArgument;
    private camelcase;
    private pluralize;
    private isReserved;
    private datesEqual;
    private openRealm;
    private getSchemaHandler;
}
